==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GatewayClassListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayClassListFluent<A extends GatewayClassListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,GatewayClass item);
  public A setToItems(Integer index,GatewayClass item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public A addAllToItems(Collection<GatewayClass> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public A removeAllFromItems(Collection<GatewayClass> items);
  public A removeMatchingFromItems(Predicate<GatewayClassBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GatewayClass> getItems();
  public List<GatewayClass> buildItems();
  public GatewayClass buildItem(Integer index);
  public GatewayClass buildFirstItem();
  public GatewayClass buildLastItem();
  public GatewayClass buildMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public A withItems(List<GatewayClass> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public Boolean hasItems();
  public GatewayClassListFluent.ItemsNested<A> addNewItem();
  public GatewayClassListFluent.ItemsNested<A> addNewItemLike(GatewayClass item);
  public GatewayClassListFluent.ItemsNested<A> setNewItemLike(Integer index,GatewayClass item);
  public GatewayClassListFluent.ItemsNested<A> editItem(Integer index);
  public GatewayClassListFluent.ItemsNested<A> editFirstItem();
  public GatewayClassListFluent.ItemsNested<A> editLastItem();
  public GatewayClassListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,GatewayClassFluent<GatewayClassListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GatewayClassListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayClassListFluent<A extends GatewayClassListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,GatewayClass item);
  public A setToItems(int index,GatewayClass item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public A addAllToItems(Collection<GatewayClass> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public A removeAllFromItems(Collection<GatewayClass> items);
  public A removeMatchingFromItems(Predicate<GatewayClassBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GatewayClass> getItems();
  public List<GatewayClass> buildItems();
  public GatewayClass buildItem(int index);
  public GatewayClass buildFirstItem();
  public GatewayClass buildLastItem();
  public GatewayClass buildMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public A withItems(List<GatewayClass> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.GatewayClass... items);
  public Boolean hasItems();
  public GatewayClassListFluent.ItemsNested<A> addNewItem();
  public GatewayClassListFluent.ItemsNested<A> addNewItemLike(GatewayClass item);
  public GatewayClassListFluent.ItemsNested<A> setNewItemLike(int index,GatewayClass item);
  public GatewayClassListFluent.ItemsNested<A> editItem(int index);
  public GatewayClassListFluent.ItemsNested<A> editFirstItem();
  public GatewayClassListFluent.ItemsNested<A> editLastItem();
  public GatewayClassListFluent.ItemsNested<A> editMatchingItem(Predicate<GatewayClassBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,GatewayClassFluent<GatewayClassListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
